import { Component } from '@angular/core';
import { FormsModule } from '@angular/forms'; // 关键修复
import { ModalController } from '@ionic/angular/standalone';
import { IonHeader, IonToolbar, IonTitle, IonButtons, 
         IonButton, IonIcon, IonContent, IonItem, 
         IonInput, IonTextarea, IonSelect, IonSelectOption,
         IonLabel, IonCheckbox } from '@ionic/angular/standalone';
import { addIcons } from 'ionicons';
import { close, save, barbell, body, walk, flame, bicycle } from 'ionicons/icons';

@Component({
  selector: 'app-plan-creation-modal',
  templateUrl: './plan-creation-modal.component.html',
  styleUrls: ['./plan-creation-modal.component.scss'],
  standalone: true,
  imports: [
    // 添加 FormsModule 以支持 ngModel
    FormsModule,
    
    // Ionic组件
    IonHeader, IonToolbar, IonTitle, IonButtons, IonButton, IonIcon,
    IonContent, IonItem, IonInput, IonTextarea, IonSelect, IonSelectOption,
    IonLabel, IonCheckbox
  ]
})
export class PlanCreationModalComponent {
  // 修复类型问题：明确指定goals为字符串数组
  newPlan = {
    name: '',
    description: '',
    duration: 4,
    difficulty: 'beginner',
    goals: [] as string[], // 明确指定为字符串数组
    icon: 'fitness'
  };

  fitnessGoals = [
    { name: '跑步', value: 'running', icon: 'walk' },
    { name: '减脂', value: 'fat_loss', icon: 'flame' },
    { name: '增肌', value: 'muscle_gain', icon: 'barbell' },
    { name: '耐力', value: 'endurance', icon: 'bicycle' },
    { name: '柔韧性', value: 'flexibility', icon: 'body' }
  ];

  constructor(private modalCtrl: ModalController) {
    addIcons({ close, save, barbell, body, walk, flame, bicycle });
  }

  cancel() {
    this.modalCtrl.dismiss(null, 'cancel');
  }

  create() {
    this.modalCtrl.dismiss(this.newPlan, 'confirm');
  }

  // 修复类型问题：明确goal为字符串
  toggleGoal(goal: string) {
    const index = this.newPlan.goals.indexOf(goal);
    if (index > -1) {
      this.newPlan.goals.splice(index, 1);
    } else {
      this.newPlan.goals.push(goal);
    }
    
    // 自动选择图标
    if (this.newPlan.goals.includes('running')) {
      this.newPlan.icon = 'walk';
    } else if (this.newPlan.goals.includes('fat_loss')) {
      this.newPlan.icon = 'flame';
    } else if (this.newPlan.goals.includes('muscle_gain')) {
      this.newPlan.icon = 'barbell';
    } else {
      this.newPlan.icon = 'fitness';
    }
  }
}